"""
Rfam_get_sequence_regions

Get list of all genomic regions containing RNA family members. Returns tab-delimited data with se...
"""

from typing import Any, Optional, Callable
from ._shared_client import get_shared_client


def Rfam_get_sequence_regions(
    operation: str,
    family_id: str,
    format: Optional[str] = "text",
    *,
    stream_callback: Optional[Callable[[str], None]] = None,
    use_cache: bool = False,
    validate: bool = True,
) -> dict[str, Any]:
    """
    Get list of all genomic regions containing RNA family members. Returns tab-delimited data with se...

    Parameters
    ----------
    operation : str
        Operation type
    family_id : str
        Required: Rfam accession or family name
    format : str
        Output format
    stream_callback : Callable, optional
        Callback for streaming output
    use_cache : bool, default False
        Enable caching
    validate : bool, default True
        Validate parameters

    Returns
    -------
    dict[str, Any]
    """
    # Handle mutable defaults to avoid B006 linting error

    return get_shared_client().run_one_function(
        {
            "name": "Rfam_get_sequence_regions",
            "arguments": {
                "operation": operation,
                "family_id": family_id,
                "format": format,
            },
        },
        stream_callback=stream_callback,
        use_cache=use_cache,
        validate=validate,
    )


__all__ = ["Rfam_get_sequence_regions"]
