"""
PubChemBioAssay_get_assay_summary

Get summary and molecular target information for a PubChem BioAssay. Returns the assay name, sour...
"""

from typing import Any, Optional, Callable
from ._shared_client import get_shared_client


def PubChemBioAssay_get_assay_summary(
    aid: int,
    *,
    stream_callback: Optional[Callable[[str], None]] = None,
    use_cache: bool = False,
    validate: bool = True,
) -> Any:
    """
    Get summary and molecular target information for a PubChem BioAssay. Returns the assay name, sour...

    Parameters
    ----------
    aid : int
        PubChem BioAssay ID (AID). Examples: 1259393, 504832, 1234.
    stream_callback : Callable, optional
        Callback for streaming output
    use_cache : bool, default False
        Enable caching
    validate : bool, default True
        Validate parameters

    Returns
    -------
    Any
    """
    # Handle mutable defaults to avoid B006 linting error

    return get_shared_client().run_one_function(
        {"name": "PubChemBioAssay_get_assay_summary", "arguments": {"aid": aid}},
        stream_callback=stream_callback,
        use_cache=use_cache,
        validate=validate,
    )


__all__ = ["PubChemBioAssay_get_assay_summary"]
