"""
STATIC LAZY REGISTRY - GENERATED FILE
Do not edit manually. generated by generate_lazy_registry.py
This file allows lazy loading to work in frozen environments where source files are missing.
"""

# Map of tool_name -> module_name
STATIC_LAZY_REGISTRY = {
    "ADMETAITool": "admetai_tool",
    "AgenticTool": "agentic_tool",
    "AlphaFoldRESTTool": "alphafold_tool",
    "ArXivTool": "arxiv_tool",
    "ArrayExpressRESTTool": "arrayexpress_tool",
    "BaseMCPClient": "mcp_client_tool",
    "BasePythonExecutor": "python_executor_tool",
    "BaseRESTTool": "base_rest_tool",
    "BaseTool": "base_tool",
    "BiGGModelsTool": "bigg_models_tool",
    "BinaryDownloadTool": "file_download_tool",
    "BioGRIDRESTTool": "biogrid_tool",
    "BioModelsRESTTool": "biomodels_tool",
    "BioRxivTool": "biorxiv_tool",
    "BioStudiesRESTTool": "biostudies_tool",
    "Boltz2DockingTool": "boltz_tool",
    "CBioPortalRESTTool": "cbioportal_tool",
    "CDCRESTTool": "cdc_tool",
    "CELLxGENECensusTool": "cellxgene_census_tool",
    "CIViCTool": "civic_tool",
    "CMAGuidelinesTool": "unified_guideline_tools",
    "CellosaurusGetCellLineInfoTool": "cellosaurus_tool",
    "CellosaurusQueryConverterTool": "cellosaurus_tool",
    "CellosaurusSearchTool": "cellosaurus_tool",
    "ChEMBLRESTTool": "chem_tool",
    "ChEMBLTool": "chem_tool",
    "ChIPAtlasTool": "chipatlas_tool",
    "ClinVarGetClinicalSignificance": "clinvar_tool",
    "ClinVarGetVariantDetails": "clinvar_tool",
    "ClinVarRESTTool": "clinvar_tool",
    "ClinVarSearchVariants": "clinvar_tool",
    "ClinicalTrialsDetailsTool": "ctg_tool",
    "ClinicalTrialsGovTool": "clinical_trials_tool",
    "ClinicalTrialsSearchTool": "ctg_tool",
    "ClinicalTrialsTool": "ctg_tool",
    "ComposeTool": "compose_tool",
    "CoreTool": "core_tool",
    "CrossrefRESTTool": "crossref_tool",
    "CustomTool": "custom_tool",
    "DBLPTool": "dblp_tool",
    "DBpediaSPARQLTool": "dbpedia_tool",
    "DGIdbTool": "dgidb_tool",
    "DOAJTool": "doaj_tool",
    "DatasetTool": "dataset_tool",
    "DbfetchRESTTool": "dbfetch_tool",
    "DetailedTermInfo": "ols_tool",
    "DigiKeyTool": "digikey_tool",
    "DiseaseTargetScoreTool": "graphql_tool",
    "DynamicPackageDiscovery": "package_discovery_tool",
    "EBISearchRESTTool": "ebi_search_tool",
    "EFOTool": "efo_tool",
    "EMDBRESTTool": "emdb_tool",
    "ENABrowserRESTTool": "ena_browser_tool",
    "ENCODERESTTool": "encode_tool",
    "ENCODESearchTool": "encode_tool",
    "EmbeddingCollectionSearchTool": "database_setup.generic_embedding_search_tool",
    "EmbeddingDatabase": "database_setup.embedding_database",
    "EmbeddingSync": "database_setup.embedding_sync",
    "EnrichrTool": "enrichr_tool",
    "EnsemblGetSequence": "ensembl_tool",
    "EnsemblGetVariants": "ensembl_tool",
    "EnsemblLookupGene": "ensembl_tool",
    "EnsemblRESTTool": "ensembl_tool",
    "EuHealthDeepDiveTool": "euhealth.euhealth_tool",
    "EuHealthTopicSearchTool": "euhealth.euhealth_tool",
    "EuropePMCGuidelinesTool": "unified_guideline_tools",
    "EuropePMCRESTTool": "europe_pmc_tool",
    "EuropePMCTool": "europe_pmc_tool",
    "ExecuteTool": "tool_discovery_tools",
    "ExecuteToolTool": "tool_discovery_tools",
    "FDACountAdditiveReactionsTool": "openfda_adv_tool",
    "FDADrugAdverseEventDetailTool": "openfda_adv_tool",
    "FDADrugAdverseEventTool": "openfda_adv_tool",
    "FDADrugInteractionDetailTool": "openfda_adv_tool",
    "FDADrugLabel": "openfda_tool",
    "FDADrugLabelAggregated": "openfda_tool",
    "FDADrugLabelFieldValueTool": "openfda_tool",
    "FDADrugLabelGetDrugGenericNameTool": "openfda_tool",
    "FDADrugLabelGetDrugNamesByIndicationAggregated": "openfda_tool",
    "FDADrugLabelGetDrugNamesByIndicationStats": "openfda_tool",
    "FDADrugLabelSearchIDTool": "openfda_tool",
    "FDADrugLabelSearchTool": "openfda_tool",
    "FDADrugLabelStats": "openfda_tool",
    "FDADrugLabelTool": "openfda_tool",
    "FDAPharmacogenomicBiomarkersTool": "fda_pharmacogenomic_biomarkers_tool",
    "FDATool": "openfda_tool",
    "FatcatScholarTool": "fatcat_tool",
    "FileDownloadTool": "file_download_tool",
    "FourDNTool": "fourdn_tool",
    "GBIFOccurrenceTool": "gbif_tool",
    "GBIFTool": "gbif_tool",
    "GDCCasesTool": "gdc_tool",
    "GDCFilesTool": "gdc_tool",
    "GEOGetDatasetInfo": "geo_tool",
    "GEOGetSampleInfo": "geo_tool",
    "GEORESTTool": "geo_tool",
    "GEOSearchDatasets": "geo_tool",
    "GINGuidelinesTool": "unified_guideline_tools",
    "GTExEQTLTool": "gtex_tool",
    "GTExExpressionTool": "gtex_tool",
    "GTExV2Tool": "gtex_v2_tool",
    "GWASAssociationByID": "gwas_tool",
    "GWASAssociationSearch": "gwas_tool",
    "GWASAssociationsForSNP": "gwas_tool",
    "GWASAssociationsForStudy": "gwas_tool",
    "GWASAssociationsForTrait": "gwas_tool",
    "GWASGeneSearch": "genomics_gene_search_tool",
    "GWASRESTTool": "gwas_tool",
    "GWASSNPByID": "gwas_tool",
    "GWASSNPSearch": "gwas_tool",
    "GWASSNPsForGene": "gwas_tool",
    "GWASStudiesForTrait": "gwas_tool",
    "GWASStudyByID": "gwas_tool",
    "GWASStudySearch": "gwas_tool",
    "GWASVariantsForTrait": "gwas_tool",
    "GeneOntologyTool": "gene_ontology_tool",
    "GetSPLBySetIDTool": "dailymed_tool",
    "GetToolInfo": "tool_discovery_tools",
    "GetToolInfoTool": "tool_discovery_tools",
    "GhostTool": "ghost_tool",
    "GraphQLTool": "graphql_tool",
    "GrepTools": "tool_discovery_tools",
    "GrepToolsTool": "tool_discovery_tools",
    "GtoPdbRESTTool": "gtopdb_tool",
    "HALTool": "hal_tool",
    "HCATool": "hca_tool",
    "HPAGetBiologicalProcessTool": "hpa_tool",
    "HPAGetCancerPrognosticsTool": "hpa_tool",
    "HPAGetComparativeExpressionTool": "hpa_tool",
    "HPAGetContextualBiologicalProcessTool": "hpa_tool",
    "HPAGetDiseaseExpressionTool": "hpa_tool",
    "HPAGetGeneJSONTool": "hpa_tool",
    "HPAGetGenePageDetailsTool": "hpa_tool",
    "HPAGetGeneXMLTool": "hpa_tool",
    "HPAGetProteinInteractionsTool": "hpa_tool",
    "HPAGetRnaExpressionBySourceTool": "hpa_tool",
    "HPAGetRnaExpressionByTissueTool": "hpa_tool",
    "HPAGetSubcellularLocationTool": "hpa_tool",
    "HPAJsonApiTool": "hpa_tool",
    "HPASearchApiTool": "hpa_tool",
    "HPASearchGenesTool": "hpa_tool",
    "HPASearchTool": "hpa_tool",
    "HPAXmlApiTool": "hpa_tool",
    "HealthDisparitiesTool": "health_disparities_tool",
    "HumanBaseTool": "humanbase_tool",
    "IEDBTool": "iedb_tool",
    "IntActRESTTool": "intact_tool",
    "InterProRESTTool": "interpro_tool",
    "JASPARRESTTool": "jaspar_tool",
    "JLCSearchTool": "jlcsearch_tool",
    "KEGGFindGenes": "kegg_tool",
    "KEGGGetGeneInfo": "kegg_tool",
    "KEGGGetPathwayInfo": "kegg_tool",
    "KEGGListOrganisms": "kegg_tool",
    "KEGGRESTTool": "kegg_tool",
    "KEGGSearchPathway": "kegg_tool",
    "ListTools": "tool_discovery_tools",
    "ListToolsTool": "tool_discovery_tools",
    "MCPAutoLoaderTool": "mcp_client_tool",
    "MCPClientTool": "mcp_client_tool",
    "MCPProxyTool": "mcp_client_tool",
    "MCPServerDiscovery": "mcp_client_tool",
    "MGnifyAnalysesTool": "mgnify_tool",
    "MGnifyStudiesTool": "mgnify_tool",
    "MPDRESTTool": "mpd_tool",
    "MarkItDownTool": "markitdown_tool",
    "MedRxivTool": "medrxiv_tool",
    "MedlinePlusRESTTool": "medlineplus_tool",
    "MetaboLightsRESTTool": "metabolights_tool",
    "MetabolomicsWorkbenchTool": "metabolomics_workbench_tool",
    "Molecule2DTool": "molecule_2d_tool",
    "Molecule3DTool": "molecule_3d_tool",
    "Monarch": "restful_tool",
    "MonarchDiseasesForMultiplePheno": "restful_tool",
    "MonarchDiseasesForMultiplePhenoTool": "restful_tool",
    "MonarchTool": "restful_tool",
    "MouserTool": "mouser_tool",
    "MyChemTool": "mygene_tool",
    "MyGeneTool": "mygene_tool",
    "MyVariantTool": "mygene_tool",
    "NCBIBlastTool": "blast_tool",
    "NCBIEUtilsTool": "ncbi_eutils_tool",
    "NHANESTool": "nhanes_tool",
    "NICEGuidelineFullTextTool": "unified_guideline_tools",
    "NICEWebScrapingTool": "unified_guideline_tools",
    "NvidiaNIMTool": "nvidia_nim_tool",
    "OBISOccurrenceTool": "obis_tool",
    "OBISTaxaTool": "obis_tool",
    "ODPHPItemList": "odphp_tool",
    "ODPHPMyHealthfinder": "odphp_tool",
    "ODPHPOutlinkFetch": "odphp_tool",
    "ODPHPRESTTool": "odphp_tool",
    "ODPHPTopicSearch": "odphp_tool",
    "OLSRESTTool": "efo_tool",
    "OLSTool": "ols_tool",
    "OSFPreprintsTool": "osf_preprints_tool",
    "OntologyInfo": "ols_tool",
    "OntologySearchResponse": "ols_tool",
    "OpenAIRETool": "openaire_tool",
    "OpenAlexGuidelinesTool": "unified_guideline_tools",
    "OpenAlexRESTTool": "openalex_tool",
    "OpenAlexTool": "openalex_tool",
    "OpenTarget": "graphql_tool",
    "OpenTargetGenetics": "graphql_tool",
    "OpentargetGeneticsTool": "graphql_tool",
    "OpentargetTool": "graphql_tool",
    "OpentargetToolDrugNameMatch": "graphql_tool",
    "PDBeAPIRESTTool": "pdbe_api_tool",
    "PMCTool": "pmc_tool",
    "PRIDERESTTool": "pride_tool",
    "PackageTool": "package_tool",
    "PagedResponse": "ols_tool",
    "PaleobiologyRESTTool": "paleobiology_tool",
    "PathwayCommonsTool": "pathway_commons_tool",
    "PharmGKBTool": "pharmgkb_tool",
    "ProteinStructure3DTool": "protein_structure_3d_tool",
    "ProteinsAPIRESTTool": "proteins_api_tool",
    "PubChemRESTTool": "pubchem_tool",
    "PubMedGuidelinesTool": "unified_guideline_tools",
    "PubMedRESTTool": "pubmed_tool",
    "PubTatorTool": "pubtator_tool",
    "PyPIPackageInspector": "pypi_package_inspector_tool",
    "PythonCodeExecutor": "python_executor_tool",
    "PythonScriptRunner": "python_executor_tool",
    "RCSBSearchTool": "rcsb_search_tool",
    "RCSBTool": "rcsb_pdb_tool",
    "RESTfulTool": "restful_tool",
    "RNAcentralGetTool": "rnacentral_tool",
    "RNAcentralSearchTool": "rnacentral_tool",
    "ReMapRESTTool": "remap_tool",
    "ReactomeRESTTool": "reactome_tool",
    "RegulomeDBRESTTool": "regulomedb_tool",
    "RemoteTool": "remote_tool",
    "RfamTool": "rfam_tool",
    "RxNormTool": "rxnorm_tool",
    "SCREENRESTTool": "screen_tool",
    "SIMBADAdvancedTool": "simbad_tool",
    "SIMBADTool": "simbad_tool",
    "STITCHTool": "stitch_tool",
    "STRINGRESTTool": "string_tool",
    "SearchSPLTool": "dailymed_tool",
    "SemanticScholarTool": "semantic_scholar_tool",
    "SmolAgentTool": "smolagent_tool",
    "TRIPDatabaseTool": "unified_guideline_tools",
    "TermInfo": "ols_tool",
    "TermSearchResponse": "ols_tool",
    "TextDownloadTool": "file_download_tool",
    "ToolFinderEmbedding": "tool_finder_embedding",
    "ToolFinderKeyword": "tool_finder_keyword",
    "ToolFinderLLM": "tool_finder_llm",
    "ToolUniverseTool": "smolagent_tool",
    "UMLSRESTTool": "umls_tool",
    "URLHTMLTagTool": "url_tool",
    "URLToPDFTextTool": "url_tool",
    "USPTOOpenDataPortalTool": "uspto_tool",
    "UniProtRESTTool": "uniprot_tool",
    "UnpaywallTool": "unpaywall_tool",
    "VisualizationTool": "visualization_tool",
    "WHOGHOQueryTool": "who_gho_tool",
    "WHOGHORESTTool": "who_gho_tool",
    "WHOGHOStatisticTool": "who_gho_tool",
    "WHOGHOTopicTool": "who_gho_tool",
    "WHOGuidelineFullTextTool": "unified_guideline_tools",
    "WHOGuidelinesTool": "unified_guideline_tools",
    "WebAPIDocumentationSearchTool": "web_search_tool",
    "WebSearchTool": "web_search_tool",
    "WikiPathwaysGetTool": "wikipathways_tool",
    "WikiPathwaysSearchTool": "wikipathways_tool",
    "WikidataSPARQLTool": "wikidata_sparql_tool",
    "WikipediaContentTool": "wikipedia_tool",
    "WikipediaSearchTool": "wikipedia_tool",
    "WikipediaSummaryTool": "wikipedia_tool",
    "WoRMSRESTTool": "worms_tool",
    "XMLDatasetTool": "xml_tool",
    "XMLTool": "xml_tool",
    "ZenodoRESTTool": "zenodo_tool",
    "dbSNPGetFrequencies": "dbsnp_tool",
    "dbSNPGetVariantByRsID": "dbsnp_tool",
    "dbSNPRESTTool": "dbsnp_tool",
    "dbSNPSearchByGene": "dbsnp_tool",
    "gnomADGetGeneConstraints": "gnomad_tool",
    "gnomADGraphQLQueryTool": "gnomad_tool",
    "gnomADGraphQLTool": "gnomad_tool",
    "CTDTool": "ctd_tool",
    "NeuroMorphoTool": "neuromorpho_tool",
    "AllenBrainTool": "allen_brain_tool",
    "GlyGenTool": "glygen_tool",
    "MGnifyExpandedTool": "mgnify_expanded_tool",
    "SGDTool": "sgd_tool",
    "NCBIDatasetsTool": "ncbi_datasets_tool",
    "EBITaxonomyTool": "ebi_taxonomy_tool",
    "AllianceGenomeTool": "alliance_genome_tool",
    "HGNCTool": "hgnc_tool",
    "BVBRCTool": "bvbrc_tool",
    "BioImageArchiveTool": "bioimage_archive_tool",
    "PlantReactomeTool": "plant_reactome_tool",
    "EnsemblVEPTool": "ensembl_vep_tool",
    "ITISTool": "itis_tool",
    "QuickGOTool": "quickgo_tool",
    "BgeeTool": "bgee_tool",
    "OMATool": "oma_tool",
    "CATHTool": "cath_tool",
    "MeSHTool": "mesh_tool",
    "HPOTool": "hpo_tool",
    "ReactomeAnalysisTool": "reactome_analysis_tool",
    "RheaTool": "rhea_tool",
    "PubChemBioAssayTool": "pubchem_bioassay_tool",
    "ENAPortalTool": "ena_portal_tool",
    "PomBaseTool": "pombase_tool",
    "BioSamplesTool": "biosamples_tool",
    "GNPSTool": "gnps_tool",
    "WormBaseTool": "wormbase_tool",
    "SwissModelTool": "swissmodel_tool",
    "ProteomeXchangeTool": "proteomexchange_tool",
    "PDBeSearchTool": "pdbe_search_tool",
    "NextstrainTool": "nextstrain_tool",
    "OpenTreeTool": "opentree_tool",
    "INaturalistTool": "inaturalist_tool",
    "NCIThesaurusTool": "nci_thesaurus_tool",
    "ClinGenARTool": "clingen_ar_tool",
    "NDExTool": "ndex_tool",
    "GOAPITool": "go_api_tool",
    "EnsemblComparaTool": "ensembl_compara_tool",
    "MonarchV3Tool": "monarch_v3_tool",
    "EBIProteinsExtTool": "ebi_proteins_ext_tool",
    "MyDiseaseTool": "mydisease_tool",
    "OxOTool": "oxo_tool",
    "InterProDomainArchTool": "interpro_domain_arch_tool",
    "WikiPathwaysExtTool": "wikipathways_ext_tool",
    "GxATool": "gxa_tool",
    "CellxGeneDiscoveryTool": "cellxgene_discovery_tool",
    "EnsemblArchiveTool": "ensembl_archive_tool",
    "KEGGExtTool": "kegg_ext_tool",
    "EnsemblMapTool": "ensembl_map_tool",
    "EnsemblOverlapTool": "ensembl_overlap_tool",
    "EnsemblXrefsTool": "ensembl_xrefs_tool",
    "EnsemblVariationExtTool": "ensembl_variation_ext_tool",
    "EBIProteinsCoordinatesTool": "ebi_proteins_coordinates_tool",
    "EBIProteinsEpitopeTool": "ebi_proteins_epitope_tool",
    "EBIProteinsInteractionsTool": "ebi_proteins_interactions_tool",
    "PDBECompoundTool": "pdbe_compound_tool",
    "PDBeLigandsTool": "pdbe_ligands_tool",
    "PDBeSIFTSTool": "pdbe_sifts_tool",
    "PDBeValidationTool": "pdbe_validation_tool",
    "RCSBAdvancedSearchTool": "rcsb_advanced_search_tool",
    "RCSBGraphQLTool": "rcsb_graphql_tool",
    "ReactomeInteractorsTool": "reactome_interactors_tool",
    "UniParcTool": "uniparc_tool",
    "UniProtLocationsTool": "uniprot_locations_tool",
    "UniProtTaxonomyTool": "uniprot_taxonomy_tool",
    "UniRefTool": "uniref_tool",
    "ClinGenDosageTool": "clingen_dosage_tool",
    "DfamTool": "dfam_tool",
    "DisProtTool": "disprot_tool",
    "GenomeNexusTool": "genome_nexus_tool",
    "GProfilerTool": "gprofiler_tool",
    "HarmonizomeTool": "harmonizome_tool",
    "MobiDBTool": "mobidb_tool",
    "OmniPathTool": "omnipath_tool",
    "OrthoDBTool": "orthodb_tool",
    "SynBioHubTool": "synbiohub_tool",
    "AlphaMissenseTool": "alphamissense_tool",
    "ArXivPDFSnippetsTool": "arxiv_tool",
    "BRENDATool": "brenda_tool",
    "BindingDBTool": "bindingdb_tool",
    "BioPortalTool": "bioportal_tool",
    "CADDTool": "cadd_tool",
    "COSMICTool": "cosmic_tool",
    "ChEBITool": "chebi_tool",
    "ClinGenTool": "clingen_tool",
    "ComplexPortalTool": "complex_portal_tool",
    "CorePDFSnippetsTool": "core_tool",
    "DailyMedSPLParserTool": "dailymed_tool",
    "DeepGOTool": "deepgo_tool",
    "DepMapTool": "depmap_tool",
    "DisGeNETTool": "disgenet_tool",
    "DiseaseOntologyTool": "disease_ontology_tool",
    "EBIProteinsFeaturesTool": "ebi_proteins_features_tool",
    "EMoleculesTool": "emolecules_tool",
    "ENCODEFilesTool": "encode_tool",
    "ENCODESearchBiosamplesTool": "encode_tool",
    "EVETool": "eve_tool",
    "EnamineTool": "enamine_tool",
    "EnsemblInfoTool": "ensembl_info_tool",
    "EnsemblLDTool": "ensembl_ld_tool",
    "EnsemblPhenotypeTool": "ensembl_phenotype_tool",
    "EnsemblRegulationTool": "ensembl_regulation_tool",
    "EnsemblSequenceTool": "ensembl_sequence_tool",
    "EpigenomicsTool": "epigenomics_tool",
    "EuroPMCAnnotationsTool": "europepmc_annotations_tool",
    "EuropePMCFullTextFetchTool": "europe_pmc_tool",
    "EuropePMCFullTextSnippetsTool": "europe_pmc_tool",
    "ExpressionAtlasTool": "expression_atlas_tool",
    "FAERSAnalyticsTool": "faers_analytics_tool",
    "FDAOrangeBookTool": "fda_orange_book_tool",
    "FoodDataCentralTool": "fooddata_central_tool",
    "GDCCNVTool": "gdc_tool",
    "GDCGeneExpressionTool": "gdc_tool",
    "GDCMutationFrequencyTool": "gdc_tool",
    "GDCProjectsTool": "gdc_tool",
    "GDCSSMTool": "gdc_tool",
    "GPCRdbTool": "gpcrdb_tool",
    "HMDBTool": "hmdb_tool",
    "ICD10Tool": "icd_tool",
    "ICDTool": "icd_tool",
    "IMGTTool": "imgt_tool",
    "IMPCTool": "impc_tool",
    "InterProEntryTool": "interpro_entry_tool",
    "InterProExtTool": "interpro_ext_tool",
    "InterProScanTool": "interproscan_tool",
    "LOINCTool": "loinc_tool",
    "LipidMapsTool": "lipidmaps_tool",
    "MetaCycTool": "metacyc_tool",
    "NCBINucleotideSearchTool": "ncbi_nucleotide_tool",
    "NCBISRATool": "ncbi_sra_tool",
    "OMIMTool": "omim_tool",
    "OncoKBTool": "oncokb_tool",
    "OrphanetTool": "orphanet_tool",
    "PANTHERTool": "panther_tool",
    "PDBe_KB_Tool": "pdbe_kb_tool",
    "PharosTool": "pharos_tool",
    "ProteinsPlusRESTTool": "proteinsplus_tool",
    "RCSBDataTool": "rcsb_data_tool",
    "ReactomeContentTool": "reactome_content_tool",
    "SASBDBRESTTool": "sasbdb_tool",
    "SAbDabTool": "sabdab_tool",
    "STRINGExtTool": "string_ext_tool",
    "SemanticScholarPDFSnippetsTool": "semantic_scholar_tool",
    "SpliceAITool": "spliceai_tool",
    "SwissDockTool": "swissdock_tool",
    "TheraSAbDabTool": "therasabdab_tool",
    "ThreeDBeaconsTool": "three_d_beacons_tool",
    "UCSCEpigenomicsTool": "epigenomics_tool",
    "UCSCGenomeTool": "ucsc_genome_tool",
    "UniChemTool": "unichem_tool",
    "UniProtIDMappingTool": "uniprot_idmapping_tool",
    "UniProtRefTool": "uniprot_ref_tool",
    "ZINCTool": "zinc_tool",
}
