"""
GtoPdb_get_target

Get detailed information about a specific pharmacological target by its GtoPdb target ID. Returns...
"""

from typing import Any, Optional, Callable
from ._shared_client import get_shared_client


def GtoPdb_get_target(
    target_id: int,
    *,
    stream_callback: Optional[Callable[[str], None]] = None,
    use_cache: bool = False,
    validate: bool = True,
) -> Optional[dict[str, Any]]:
    """
    Get detailed information about a specific pharmacological target by its GtoPdb target ID. Returns...

    Parameters
    ----------
    target_id : int
        GtoPdb target identifier (e.g., 290 for adenosine A1 receptor). Find target I...
    stream_callback : Callable, optional
        Callback for streaming output
    use_cache : bool, default False
        Enable caching
    validate : bool, default True
        Validate parameters

    Returns
    -------
    Optional[dict[str, Any]]
    """
    # Handle mutable defaults to avoid B006 linting error

    return get_shared_client().run_one_function(
        {"name": "GtoPdb_get_target", "arguments": {"target_id": target_id}},
        stream_callback=stream_callback,
        use_cache=use_cache,
        validate=validate,
    )


__all__ = ["GtoPdb_get_target"]
