"""
ChEBI_search

Search the ChEBI database for chemical entities by name, formula, or keyword. Uses Elasticsearch-...
"""

from typing import Any, Optional, Callable
from ._shared_client import get_shared_client


def ChEBI_search(
    query: str,
    limit: Optional[int | Any] = None,
    *,
    stream_callback: Optional[Callable[[str], None]] = None,
    use_cache: bool = False,
    validate: bool = True,
) -> Any:
    """
    Search the ChEBI database for chemical entities by name, formula, or keyword. Uses Elasticsearch-...

    Parameters
    ----------
    query : str
        Search query string - compound name, synonym, formula, or keyword. Examples: ...
    limit : int | Any
        Maximum number of results to return. Default: 10. Max: 100.
    stream_callback : Callable, optional
        Callback for streaming output
    use_cache : bool, default False
        Enable caching
    validate : bool, default True
        Validate parameters

    Returns
    -------
    Any
    """
    # Handle mutable defaults to avoid B006 linting error

    return get_shared_client().run_one_function(
        {"name": "ChEBI_search", "arguments": {"query": query, "limit": limit}},
        stream_callback=stream_callback,
        use_cache=use_cache,
        validate=validate,
    )


__all__ = ["ChEBI_search"]
