"""
OpenTargets_get_variant_credible_sets

Get GWAS credible sets (fine-mapped loci) associated with a genetic variant from Open Targets. Re...
"""

from typing import Any, Optional, Callable
from ._shared_client import get_shared_client


def OpenTargets_get_variant_credible_sets(
    variantId: str,
    size: Optional[int] = 10,
    *,
    stream_callback: Optional[Callable[[str], None]] = None,
    use_cache: bool = False,
    validate: bool = True,
) -> Any:
    """
    Get GWAS credible sets (fine-mapped loci) associated with a genetic variant from Open Targets. Re...

    Parameters
    ----------
    variantId : str
        Open Targets variant ID in format chr_position_ref_alt (e.g., '10_112998590_C...
    size : int
        Number of credible sets to return (default 10)
    stream_callback : Callable, optional
        Callback for streaming output
    use_cache : bool, default False
        Enable caching
    validate : bool, default True
        Validate parameters

    Returns
    -------
    Any
    """
    # Handle mutable defaults to avoid B006 linting error

    return get_shared_client().run_one_function(
        {
            "name": "OpenTargets_get_variant_credible_sets",
            "arguments": {"variantId": variantId, "size": size},
        },
        stream_callback=stream_callback,
        use_cache=use_cache,
        validate=validate,
    )


__all__ = ["OpenTargets_get_variant_credible_sets"]
