"""
gnomad_get_region

Get basic regional information from gnomAD by genomic interval. Returns genes overlapping the reg...
"""

from typing import Any, Optional, Callable
from ._shared_client import get_shared_client


def gnomad_get_region(
    chrom: str,
    start: int,
    stop: int,
    reference_genome: Optional[str] = "GRCh38",
    dataset: Optional[str] = "gnomad_r3",
    *,
    stream_callback: Optional[Callable[[str], None]] = None,
    use_cache: bool = False,
    validate: bool = True,
) -> dict[str, Any]:
    """
    Get basic regional information from gnomAD by genomic interval. Returns genes overlapping the reg...

    Parameters
    ----------
    chrom : str
        Chromosome (e.g., '19').
    start : int
        1-based start position.
    stop : int
        1-based stop position.
    reference_genome : str
        Reference genome.
    dataset : str
        gnomAD dataset ID used for `variants(dataset: ...)`. Allowed values: gnomad_r...
    stream_callback : Callable, optional
        Callback for streaming output
    use_cache : bool, default False
        Enable caching
    validate : bool, default True
        Validate parameters

    Returns
    -------
    dict[str, Any]
    """
    # Handle mutable defaults to avoid B006 linting error

    return get_shared_client().run_one_function(
        {
            "name": "gnomad_get_region",
            "arguments": {
                "chrom": chrom,
                "start": start,
                "stop": stop,
                "reference_genome": reference_genome,
                "dataset": dataset,
            },
        },
        stream_callback=stream_callback,
        use_cache=use_cache,
        validate=validate,
    )


__all__ = ["gnomad_get_region"]
